@@ -1,5 +1,7 @@
 import base64
 
+import pytest
+
 from bluetooth_data_tools import (
     parse_advertisement_data,
     parse_advertisement_data_tuple,
@@ -486,6 +488,28 @@ def test_manufacturer_data_short_by_three():
     )
 
 
+def test_manufacturer_data_short_by_five():
+    """Test short manufacturer data."""
+
+    data = (b"\x05\xff\x01\x01\x01",)
+
+    adv = parse_advertisement_data(data)
+
+    assert adv.local_name is None
+    assert adv.service_uuids == []
+    assert adv.service_data == {}
+    assert adv.manufacturer_data == {}
+    assert adv.tx_power is None
+
+    assert parse_advertisement_data_tuple(tuple(data)) == (
+        None,
+        [],
+        {},
+        {},
+        None,
+    )
+
+
 def test_manufacturer_data_single_byte():
     """Test single byte manufacturer data."""
 
@@ -611,7 +635,119 @@ def test_zero_padded_out_of_bounds_length():
     assert adv.manufacturer_data == {}
     assert adv.tx_power is None
 
-    assert parse_advertisement_data_tuple(tuple(data)) == (
+    assert parse_advertisement_data_tuple(
+        tuple(
+            data,
+        )
+    ) == (
+        None,
+        [],
+        {},
+        {},
+        None,
+    )
+
+
+def test_data_shorter_than_length() -> None:
+    """Test data shorter than length."""
+
+    for len in range(0, 30):
+        data = bytes((len,)) + b"!\x01"
+
+        adv = parse_advertisement_data((data,))
+
+        assert adv.local_name is None
+        assert adv.service_uuids == []
+        assert adv.service_data == {}
+        assert adv.manufacturer_data == {}
+        assert adv.tx_power is None
+
+        assert parse_advertisement_data_tuple((data,)) == (
+            None,
+            [],
+            {},
+            {},
+            None,
+        )
+
+
+@pytest.mark.parametrize(
+    "data",
+    [
+        (b"\x02 a\xc4|\x04@*'\x9c\xa5C\r\xa1\xe6\x1e\xe7\x8f\xa57D\xe6$\x03",),
+        (
+            b"\xe8\x9d\x83\x8b\x96\x85\x07U\x19$&\x1c\x91\x80\xba\x04Z",
+            b'"EU\xcb\x11\xeb\xdc\xd4)\xc9\x1b\x8c\xfe\x1e\xd7\xca\x98\xfe\xcd%\xf6>\xbb\xe3\xbc\xfc5',
+            b"(\x86\x18\xe9m>\x89\xa7\xe1=\x9fE\x0f\xbcE\xb2<",
+        ),
+        (
+            b"\xf4\x9e\x0f!\x93n\xae\x1e\x89\xc2\xb4\x97\x98\xdc~\x9a\xb3\x06\x7f\x11",
+            b"\x89\xc2\x07\xff\xe7QEG&;\x06\xab\xebN\xf5\xc4g\xfe",
+            b"\xeb\x852\x0b,KB",
+        ),
+        (
+            b'\xcbu\xa5\xe4\xa1\xdd`c\x88\xa9\xe2\xaah\xe5"%X\x87\xf0',
+            b'\xac;\x8f\xc43!\xb0?"\xb8\n<',
+            b"\x10nyT\xed\x96\x07\x9a",
+        ),
+        (
+            b"\r\xd6'\xder\xfc@T\xb3Q\x12EH\x9e\xe9\xf8x\xe3\xcc\ti\xfb",
+            b"\xfe@\x89",
+            b"Gt\xc3_\xf9\x8e\xdd#",
+        ),
+        (
+            b'\x17b\x02c\xbe%"\x06\xfe\x05c4\x04\x97\x03)|\xd0\xf4\xeb~\xb1gI',
+            b"r\xc0\x9a>^o\xcb\xdb\xc2r\xca\x1a'VL\xac\xd7\x8e\xa7\xeb\xc2:\xe2_\x96\xe31r",
+            b"\\^\xe6\x96]%\x17\x02\xa5\xdcAE\x92\xb2\x1c\x1a\xd4Y\x07\xddZ\xebC\x12B\xb6\xcb\x8a",
+        ),
+        (
+            b"\x1b\x87c\xb7\x12nK\xf3_\xb4\x18)x<\xe2\x05\xc8\xdb\xf8\x1b\xf7 \xe6\x99\xe3Z\xd1C\x88\xda\x98",
+            b"\xbb\xbe@,\xa6\xdcj*\x85u\xe3\xc4",
+            b"w\xb7\xeb\xb0",
+        ),
+        (
+            b"\x88\x83\x7fN\xd0E\xa6\xc5(h\xcd\xe7\x80\\\xf0\xe6n:\x10K\x02\x92",
+            b"\xc5\xe6`a\xf7\xf5 \x1eV\xd6]8$\xf0\xf0",
+            b"\x01rS\xf1\xe2ht\xd6\x8f\xc6\x0e\xd0~",
+        ),
+        (
+            b"\x10\xa6\xc4}\xb6\xc9n\x00",
+            b"\xa8\xd8#'@\xde\x9a\xf6;&\x88\x0f\xc1m\xe5v\xa3\x17O\x8b\x92\x94\\\x91\x8b\xee\xa1\xed",
+            b'\xccA\x9c\x01;\xd1\xe8e\xeb\xf3\x8b\xa1\xd6\xe5P]\xc7"_@\x10\x1e\x8b\x90o\r\xd9',
+        ),
+    ],
+)
+def test_negative_splice_pos_does_not_crash(data: tuple[bytes, bytes, bytes]) -> None:
+    """Test data that would cause a negative splice position.
+
+    All of the data here will result in a negative splice position
+    when attempting to parse the advertisement data. This is a
+    regression test to ensure that the parser does not crash
+    when it encounters this data.
+
+    A negative splice position is caused by the parser
+    attempting to splice the data at a position that is
+    greater than the length of the data. This can happen
+    when the data is malformed or when the parser is
+    attempting to parse data that is not in the expected
+    format. The parser should be able to handle this
+    gracefully and return an empty advertisement object
+    without crashing.
+    """
+
+    adv = parse_advertisement_data(data)
+
+    assert adv.local_name is None
+    assert adv.service_uuids == []
+    assert adv.service_data == {}
+    assert adv.manufacturer_data == {}
+    assert adv.tx_power is None
+
+    assert parse_advertisement_data_tuple(
+        tuple(
+            data,
+        )
+    ) == (
         None,
         [],
         {},
